@@ -40,8 +40,14 @@ if {[string match "*ERROR*" [get_property STATUS [get_runs *synth_1]]]} {
 # Open Block Design
 open_bd_design ${::AIT::name_Project}/${::AIT::name_Project}.srcs/sources_1/bd/${::AIT::name_Design}/${::AIT::name_Design}.bd
 
-# Generate .bin file
-set_property STEPS.WRITE_BITSTREAM.ARGS.BIN_FILE true [get_runs impl_1]
+# Generate .bin file for Zynq and ZynqMP boards
+if {(${::AIT::arch_device} eq "zynq") || (${::AIT::arch_device} eq "zynqmp")} {
+    set_property STEPS.WRITE_BITSTREAM.ARGS.BIN_FILE true [get_runs impl_1]
+} else {
+    set_property STEPS.WRITE_BITSTREAM.ARGS.BIN_FILE false [get_runs impl_1]
+}
+
+AIT::info_msg "Launching implementation run with ${::AIT::num_jobs} jobs"
 
 # Launch implementation
 reset_run impl_1
@@ -51,7 +57,11 @@ wait_on_run impl_1
 
 # Check if implementation finished correctly
 if {[string match "*ERROR*" [get_property STATUS [get_runs *impl_1]]]} {
-    AIT::info_msg "Failed impl_1 implementation: [exec grep ERROR ${::AIT::name_Project}/${::AIT::name_Project}.runs/impl_1/runme.log]"
+    if {[catch {exec exec grep ^ERROR ${::AIT::name_Project}/${::AIT::name_Project}.runs/impl_1/runme.log}]} {
+        AIT::info_msg "Failed impl_1 implementation"
+    } else {
+        AIT::info_msg "Failed impl_1 implementation: [exec grep ^ERROR ${::AIT::name_Project}/${::AIT::name_Project}.runs/impl_1/runme.log]"
+    }
     AIT::error_msg "Hardware implementation failed."
 }
 
